==> haskell-skylighting-core-0.14-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 skylighting-core
version:              0.14
visibility:           public
id:                   skylighting-core-0.14-CY95pzi78Ih49NXmkTZRpH
key:                  skylighting-core-0.14-CY95pzi78Ih49NXmkTZRpH
license:              BSD-3-Clause
copyright:            (C) 2016-2018 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             syntax highlighting library
description:
    Skylighting is a syntax highlighting library.
    It derives its tokenizers from XML syntax
    definitions used by KDE'\''s KSyntaxHighlighting
    framework, so any syntax supported by that
    framework can be added. An optional command-line
    program is provided.
    Skylighting is intended to be the successor to
    highlighting-kate.
    This package provides the core highlighting
    functionality under a permissive license. It also
    bundles XML parser definitions licensed under the
    GPL.

category:             Text
abi:                  c05b639a7322dba8e0a46c8de3a6164b
exposed:              True
exposed-modules:
    Skylighting.Core Skylighting.Loader Skylighting.Parser
    Skylighting.Regex Skylighting.Styles Skylighting.Tokenizer
    Skylighting.Types

hidden-modules:
    Regex.KDE Regex.KDE.Regex Regex.KDE.Compile Regex.KDE.Match

import-dirs:          /usr/lib/ghc-9.2.8/site-local/skylighting-core-0.14
library-dirs:         /usr/lib/ghc-9.2.8/site-local/skylighting-core-0.14
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-core
hs-libraries:         HSskylighting-core-0.14-CY95pzi78Ih49NXmkTZRpH
depends:
    aeson-2.1.2.1-CCP80pZvZcA8gRL3g3IUms
    attoparsec-0.14.4-LhljGCg6FhTCY2JBHQACd0 base-4.16.4.0
    base64-bytestring-1.2.1.0-GhhDq9m6ztyC3DoGamjFCy binary-0.8.9.0
    bytestring-0.11.4.0 case-insensitive-1.2.1.0-GnsQmMXoRNL8LIaETetIqx
    colour-2.3.6-HdI1cmU1Wok1ucyzh0SdSS containers-0.6.5.1
    directory-1.3.6.2 filepath-1.4.2.2 mtl-2.2.2
    safe-0.3.21-FHqmWeL515h1ZDkEwV0YZX text-1.2.5.0
    transformers-0.5.6.2 utf8-string-1.0.2-9i4m1tpDbmh81tMCrQ25jI
    xml-conduit-1.9.1.3-5eKxJA9dp1OCxaIDJ2z8fH

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-core/html/skylighting-core.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-core/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skylighting-core-0.14-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 skylighting-core
version:              0.14
visibility:           public
id:                   skylighting-core-0.14-2n13VTXuZfh1Yy58ZrkMqt
key:                  skylighting-core-0.14-2n13VTXuZfh1Yy58ZrkMqt
license:              BSD-3-Clause
copyright:            (C) 2016-2018 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             syntax highlighting library
description:
    Skylighting is a syntax highlighting library.
    It derives its tokenizers from XML syntax
    definitions used by KDE'\''s KSyntaxHighlighting
    framework, so any syntax supported by that
    framework can be added. An optional command-line
    program is provided.
    Skylighting is intended to be the successor to
    highlighting-kate.
    This package provides the core highlighting
    functionality under a permissive license. It also
    bundles XML parser definitions licensed under the
    GPL.

category:             Text
abi:                  70673529f13f09236f142f30c70af643
exposed:              True
exposed-modules:
    Skylighting.Core Skylighting.Loader Skylighting.Parser
    Skylighting.Regex Skylighting.Styles Skylighting.Tokenizer
    Skylighting.Types

hidden-modules:
    Regex.KDE Regex.KDE.Regex Regex.KDE.Compile Regex.KDE.Match

import-dirs:          /usr/lib/ghc-9.2.8/site-local/skylighting-core-0.14
library-dirs:         /usr/lib/ghc-9.2.8/site-local/skylighting-core-0.14
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-core
hs-libraries:         HSskylighting-core-0.14-2n13VTXuZfh1Yy58ZrkMqt
depends:
    aeson-2.1.2.1-CCP80pZvZcA8gRL3g3IUms
    attoparsec-0.14.4-LhljGCg6FhTCY2JBHQACd0 base-4.16.4.0
    base64-bytestring-1.2.1.0-GhhDq9m6ztyC3DoGamjFCy binary-0.8.9.0
    bytestring-0.11.4.0 case-insensitive-1.2.1.0-GnsQmMXoRNL8LIaETetIqx
    colour-2.3.6-HdI1cmU1Wok1ucyzh0SdSS containers-0.6.5.1
    directory-1.3.6.2 filepath-1.4.2.2 mtl-2.2.2
    safe-0.3.21-FHqmWeL515h1ZDkEwV0YZX text-1.2.5.0
    transformers-0.5.6.2 utf8-string-1.0.2-9i4m1tpDbmh81tMCrQ25jI
    xml-conduit-1.9.1.3-BzuBXTkhEcjK9z9wbeBQIQ

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-core/html/skylighting-core.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-core/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
